Module protocol

Module protocol 

Functions

build_identify_command
Build the identify command bytes for a lighthouse (V2 only).
build_power_command
Build the power control command bytes for a lighthouse.
build_sleep_command
Build the sleep control command bytes for a lighthouse.
build_v1_power_on
Build the power-on command bytes for a V1 lighthouse. Format: [0x12, 0x00, 0x00, 0x00] + reversed ID bytes (4) + [0x00; 12] = 20 bytes total.
build_v1_sleep
Build the sleep command bytes for a V1 lighthouse. Format: [0x12, 0x02, 0x00, 0x01] + reversed ID bytes (4) + [0x00; 12] = 20 bytes total.
build_v2_identify
Build the identify command for a V2 lighthouse.
build_v2_power_on
Build the power-on command for a V2 lighthouse.
build_v2_sleep
Build the sleep command for a V2 lighthouse.