pub fn load() -> Result<AppSettings>Expand description
Load settings from disk (using the default config path). Returns defaults if file doesn’t exist.
Errors
Returns an error if the config directory cannot be determined.
pub fn load() -> Result<AppSettings>Load settings from disk (using the default config path). Returns defaults if file doesn’t exist.
Returns an error if the config directory cannot be determined.