pub async fn scan_until_predicate<F>(
adapter: &Adapter,
predicate: F,
) -> Result<HashSet<String>>Expand description
Start a BLE scan, poll until a predicate is satisfied (or timeout), then stop the scan. Returns the final set of discovered peripheral addresses (lowercase).
Errors
Returns an error if the initial BLE scan fails to start.