pub fn save(settings: &AppSettings) -> Result<()>Expand description
Save settings to disk (using the default config path).
Errors
Returns an error if the config directory cannot be determined, the JSON cannot be serialized, or the file cannot be written.